@@ -32,9 +32,11 @@ class Node(pyeapi.client.Node):
         :param kwargs: other args
         :return: list of outputs
         """
-        if isinstance(commands, str):
-            new_commands = [cli_convert(commands, self.cli_version)]
-        else:
-            new_commands = [cli_convert(cmd, self.cli_version) for cmd in commands]
+        fn0039_transform = kwargs.pop("fn0039_transform", True)
+        if fn0039_transform:
+            if isinstance(commands, str):
+                commands = [cli_convert(commands, self.cli_version)]
+            else:
+                commands = [cli_convert(cmd, self.cli_version) for cmd in commands]
 
-        return super(Node, self).run_commands(new_commands, **kwargs)
+        return super(Node, self).run_commands(commands, **kwargs)
